@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Gufw 11.04.2 - http://gufw.tuxfamily.org
+# Gufw 11.10.2 - http://gufw.tuxfamily.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -16,16 +16,15 @@
 # along with Gufw; if not, see http://www.gnu.org/licenses for more
 # information.
 
-import gobject
 import time
 import commands
+
+from gi.repository import GObject
 import dbus
 import dbus.service
 import dbus.mainloop.glib
 from dbus.exceptions import DBusException
 
-
-
 class DemoException(dbus.DBusException):
     _dbus_error_name = 'gufw.DemoException'
 
@@ -39,7 +38,7 @@ class PermissionDeniedByPolicy(dbus.DBusException):
 class Gufw_daemon(dbus.service.Object):
     
     def __init__(self, conn=None, object_path=None, bus_name=None):
-        dbus.service.Object.__init__(self,conn,object_path,bus_name)
+        dbus.service.Object.__init__(self, conn, object_path, bus_name)
         self.enforce_polkit = True
         self.dbus_info      = None
         self.polkit         = None
@@ -92,7 +91,7 @@ class Gufw_daemon(dbus.service.Object):
     @dbus.service.method("gufw.SampleInterface",
                      in_signature='', out_signature='',
                      sender_keyword='sender', connection_keyword='conn')
-    def fw_unblock(self, sender=None, conn=None):
+    def fw_unlock(self, sender=None, conn=None):
         """PolicyKit"""
         self._check_polkit_privilege(sender, conn, 'gufw.daemon.start')
             
@@ -142,7 +141,7 @@ class Gufw_daemon(dbus.service.Object):
                      in_signature='', out_signature='s',
                      sender_keyword='sender', connection_keyword='conn')
     def get_ufw_logging(self, sender=None, conn=None):
-        """Get Inicial ufw Logging"""
+        """Get Initial ufw Logging"""
         dbus_info_aux = dbus.Interface(conn.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus/Bus', False), 'org.freedesktop.DBus')
         if ( self.__caller_pid__ == 0 ) or ( self.__caller_pid__ != dbus_info_aux.GetConnectionUnixProcessID(sender) ):
             return "no_access"
@@ -231,7 +230,7 @@ class Gufw_daemon(dbus.service.Object):
                      in_signature='', out_signature='s',
                      sender_keyword='sender', connection_keyword='conn')
     def reset_ufw(self, sender=None, conn=None):
-        """Reset cofig ufw"""
+        """Reset ufw config"""
         dbus_info_aux = dbus.Interface(conn.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus/Bus', False), 'org.freedesktop.DBus')
         if ( self.__caller_pid__ == 0 ) or ( self.__caller_pid__ != dbus_info_aux.GetConnectionUnixProcessID(sender) ):
             return "no_access"
@@ -244,7 +243,7 @@ class Gufw_daemon(dbus.service.Object):
                      in_signature='', out_signature='',
                      sender_keyword='sender', connection_keyword='conn')
     def erase_gufw_log(self, sender=None, conn=None):
-        """Erase all Gufw Log"""
+        """Erase all Gufw Logs"""
         dbus_info_aux = dbus.Interface(conn.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus/Bus', False), 'org.freedesktop.DBus')
         if ( self.__caller_pid__ == 0 ) or ( self.__caller_pid__ != dbus_info_aux.GetConnectionUnixProcessID(sender) ):
             return
@@ -282,7 +281,7 @@ class Gufw_daemon(dbus.service.Object):
                      in_signature='', out_signature='i',
                      sender_keyword='sender', connection_keyword='conn')
     def get_number_rules(self, sender=None, conn=None):
-        """Get the number of actually rules"""
+        """Get the actual number of rules"""
         dbus_info_aux = dbus.Interface(conn.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus/Bus', False), 'org.freedesktop.DBus')
         if ( self.__caller_pid__ == 0 ) or ( self.__caller_pid__ != dbus_info_aux.GetConnectionUnixProcessID(sender) ):
             return 0
@@ -478,7 +477,8 @@ class Gufw_daemon(dbus.service.Object):
         
         commands.getstatusoutput(rule)
         return rule
-    
+
+
 if __name__ == '__main__':
     dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
     
@@ -486,5 +486,5 @@ if __name__ == '__main__':
     name = dbus.service.BusName("gufw.Daemon", bus)
     object = Gufw_daemon(bus, '/Gufw_daemon')
 
-    mainloop = gobject.MainLoop()
+    mainloop = GObject.MainLoop()
     mainloop.run()
