@@ -1,4 +1,4 @@
-# Gufw 11.04.2 - http://gufw.tuxfamily.org
+# Gufw 11.10.0 - http://gufw.tuxfamily.org
 # Copyright (C) 2008-2011 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -18,11 +18,15 @@
 import commands
 import time
 import os
+
 import dbus
 
+# Work around a bug in python-distutils-extra auto, fixed in p-d-e rev 258
+# org.freedesktop.PolicyKit1
+
 
 class Firewall():
-    """Set or get the properties of Firewall"""
+    """Set or get the Firewall properties"""
     
     WIN_WIDTH = 336
     WIN_HEIGHT = 334
@@ -41,10 +45,10 @@ class Firewall():
         self.vpanel           = self.WIN_VPANEL
         self._read_config_file()
     
-    def unblock(self):
-        """Unblock by PolicyKit"""
+    def unlock(self):
+        """Unlock by PolicyKit"""
         try:
-            self.iface.fw_unblock()
+            self.iface.fw_unlock()
         except:
             return "no_access"
             
@@ -148,7 +152,7 @@ class Firewall():
         self.iface.add_gufw_log(self.gufw_logging, line)
         
     def erase_gufw_log(self):
-        """Erase all Gufw Log"""
+        """Erase all Gufw Logs"""
         self.iface.erase_gufw_log()
         
     def add_rule(self, is_program, insert_number, action, direction, log, protocol, fromip, fromport, toip, toport):
@@ -160,7 +164,7 @@ class Firewall():
         self._add_gufw_log(self.iface.remove_rule(str(number)))
     
     def get_number_rules(self):
-        """Get the number of actually rules"""
+        """Get the actual number of rules"""
         return self.iface.get_number_rules()
     
     def get_rule_list(self):
@@ -168,12 +172,12 @@ class Firewall():
         return self.iface.get_rule_list()
     
     def update_config_file(self, width, height, vpanel):
-        """Save actual FW config when quit Gufw"""
+        """Save actual FW config when quitting Gufw"""
         self.iface.update_config_file(width, height, vpanel, self.gufw_logging, self.listening_status, self.notify_popup)
         self.iface.Exit()
     
     def _read_config_file(self):
-        """Get previus values from config file """
+        """Get previous values from config file """
         file = commands.getstatusoutput("cat /etc/gufw/gufw.cfg")
         if file[0] != 0:
             return
