@@ -1,4 +1,4 @@
-# Gufw 11.04.2 - http://gufw.tuxfamily.org
+# Gufw 11.10.2 - http://gufw.tuxfamily.org
 # Copyright (C) 2008-2011 Raul Soriano https://launchpad.net/~gatoloko
 #                         Marcos Alvarez Costales https://launchpad.net/~costales
 #
@@ -28,7 +28,7 @@ class Validation:
         self._start_application()
     
     def _check_instance(self):
-        """Check wether the app is running"""
+        """Check whether the app is running"""
         if not os.path.isfile(self.pid_file):
             return
 
@@ -42,7 +42,7 @@ class Validation:
         except:
             pass
         
-        # Check wether the proccess specified exists
+        # Check whether the process specified exists
         if 0 == pid:
             return
         try:
@@ -71,7 +71,7 @@ class Path:
     """Return app paths"""
     def get_ui_path(self, file_name):
         """Return Path GUI"""
-        path = os.path.join('/usr', 'share', 'gufw', 'data', 'ui', file_name)
+        path = os.path.join('/usr', 'share', 'gufw', 'ui', file_name)
         if not os.path.exists(path):
             path = os.path.join('data', 'ui', file_name)
         return path
@@ -79,7 +79,7 @@ class Path:
     def get_shield_path(self, incoming, outgoing):
         """Return Path Shields"""
         file_name = incoming + '_' + outgoing + '.png'
-        path = os.path.join('/usr', 'share', 'gufw', 'data', 'media', file_name)
+        path = os.path.join('/usr', 'share', 'gufw', 'media', file_name)
         if not os.path.exists(path):
             path = os.path.join('data', 'media', file_name)
         return path
